'use strict';
var commander = require('commander');
var fs = require('fs');
var path = require('path');
var series_1 = require('./series');
/**
 * Streams the batch of series to disk.
 */
function default_1(args, done) {
    var config = parse(args);
    var batchPath = path.join(config.output || process.cwd(), 'CrunchyRoll.txt');
    tasks(config, batchPath, function (err, tasks) {
        if (err)
            return done(err);
        var i = 0;
        (function next() {
            if (i >= tasks.length)
                return done();
            series_1.default(tasks[i].config, tasks[i].address, function (err) {
                if (err)
                    return done(err);
                i += 1;
                next();
            });
        })();
    });
}
exports.default = default_1;
/**
 * Splits the value into arguments.
 */
function split(value) {
    var inQuote = false;
    var i;
    var pieces = [];
    var previous = 0;
    for (i = 0; i < value.length; i += 1) {
        if (value.charAt(i) === '"')
            inQuote = !inQuote;
        if (!inQuote && value.charAt(i) === ' ') {
            pieces.push(value.substring(previous, i).match(/^"?(.+?)"?$/)[1]);
            previous = i + 1;
        }
    }
    var lastPiece = value.substring(previous, i).match(/^"?(.+?)"?$/);
    if (lastPiece)
        pieces.push(lastPiece[1]);
    return pieces;
}
/**
 * Parses the configuration or reads the batch-mode file for tasks.
 */
function tasks(config, batchPath, done) {
    if (config.args.length) {
        return done(null, config.args.map(function (address) {
            return { address: address, config: config };
        }));
    }
    fs.exists(batchPath, function (exists) {
        if (!exists)
            return done(null, []);
        fs.readFile(batchPath, 'utf8', function (err, data) {
            if (err)
                return done(err);
            var map = [];
            data.split(/\r?\n/).forEach(function (line) {
                if (/^(\/\/|#)/.test(line))
                    return;
                var lineConfig = parse(process.argv.concat(split(line)));
                lineConfig.args.forEach(function (address) {
                    if (!address)
                        return;
                    map.push({ address: address, config: lineConfig });
                });
            });
            done(null, map);
        });
    });
}
/**
 * Parses the arguments and returns a configuration.
 */
function parse(args) {
    return new commander.Command().version(require('../package').version)
        .option('-p, --pass <s>', 'The password.')
        .option('-u, --user <s>', 'The e-mail address or username.')
        .option('-c, --cache', 'Disables the cache.')
        .option('-m, --merge', 'Disables merging subtitles and videos.')
        .option('-e, --episode <i>', 'The episode filter.')
        .option('-v, --volume <i>', 'The volume filter.')
        .option('-f, --format <s>', 'The subtitle format. (Default: ass)')
        .option('-o, --output <s>', 'The output path.')
        .option('-s, --series <s>', 'The series override.')
        .option('-t, --tag <s>', 'The subgroup. (Default: CrunchyRoll)')
        .parse(args);
}
//# sourceMappingURL=batch.js.map