'use strict';
var request = require('request');
var isAuthenticated = false;
/**
 * Performs a GET request for the resource.
 */
function get(config, options, done) {
    authenticate(config, function (err) {
        if (err)
            return done(err);
        request.get(modify(options), function (err, response, body) {
            if (err)
                return done(err);
            done(null, typeof body === 'string' ? body : String(body));
        });
    });
}
exports.get = get;
/**
 * Performs a POST request for the resource.
 */
function post(config, options, done) {
    authenticate(config, function (err) {
        if (err)
            return done(err);
        request.post(modify(options), function (err, response, body) {
            if (err)
                return done(err);
            done(null, typeof body === 'string' ? body : String(body));
        });
    });
}
exports.post = post;
/**
 * Authenticates using the configured pass and user.
 */
function authenticate(config, done) {
    if (isAuthenticated || !config.pass || !config.user)
        return done(null);
    var options = {
        form: {
            formname: 'RpcApiUser_Login',
            fail_url: 'https://www.crunchyroll.com/login',
            name: config.user,
            password: config.pass
        },
        jar: true,
        url: 'https://www.crunchyroll.com/?a=formhandler'
    };
    request.post(options, function (err) {
        if (err)
            return done(err);
        isAuthenticated = true;
        done(null);
    });
}
/**
 * Modifies the options to use the authenticated cookie jar.
 */
function modify(options) {
    if (typeof options !== 'string') {
        options.jar = true;
        return options;
    }
    return { jar: true, url: options.toString() };
}
//# sourceMappingURL=request.js.map